package SPVM::Mojo::Message::Request;



1;

=head1 Name

SPVM::Mojo::Message::Request - HTTP Request

=head1 Description

The Mojo::Message::Request class of L<SPVM> has methods to manipulate HTTP requests.

This class is a private class.

=head1 Copyright & License

Copyright (c) 2023 Yuki Kimoto

MIT License

