package SPVM::Mojo::Message;



1;

=head1 Name

SPVM::Mojo::Message - Base class of HTTP Request/Response

=head1 Description

The Mojo::Message class of L<SPVM> has methods to manipulate HTTP message.

This class is an abstract class for child classes.

=head1 Copyright & License

Copyright (c) 2023 Yuki Kimoto

MIT License

