package SPVM::Mojo::UserAgent::CookieJar::Callback::Ignore;



1;

=head1 Name

SPVM::Mojo::UserAgent::CookieJar::Callback::Ignore - Short Description

=head1 Description

Mojo::UserAgent::CookieJar::Callback::Ignore interface in L<SPVM> has interface methods to do someting.

=head1 Usage

  interface Mojo::UserAgent::CookieJar::Callback::Ignore;

=head1 Details



=head1 Interface Methods




=head1 Repository



=head1 Author

[--user-name] C<[--user-email]>

=head1 Copyright & License

Copyright (c) 2025 [--user-name]

MIT License

