package SPVM::Mojo::Upload;



1;

=head1 Name

SPVM::Mojo::Upload - Short Description

=head1 Description

Mojo::Upload class in L<SPVM> has methods to do someting.

=head1 Usage

  use Mojo::Upload;

=head1 Details



=head1 Super Class



=head1 Interfaces



=head1 Enumerations



=head1 Fields



=head1 Class Methods



=head1 Instance Methods



=head1 See Also




=head1 Repository



=head1 Author

Yuki Kimoto C<kimoto.yuki@gmail.com>

=head1 Copyright & License

Copyright (c) 2025 Yuki Kimoto

MIT License

